class shibbolethsp::configure(
  $idp_name,
  $idp_entity_id,
  $idp_metadata_uri,
  $idp_metadata_backing,
  $idp_sig_cert,
  $idp_sig_cert_name,
  $sp_entity_id,
  $sp_remote_user_attributes,
  $sp_support_contact,
  $sp_cert,
  $sp_key,
  $http_process_user,
  $sp_mapped_attributes,
  $sp_force_authn,
  $logout_redirect_uri,
  $sessions_lifetime = 28800,
  $sessions_timeout = 3600,
) {

  concat{ $shibbolethsp::params::sp_config_file:
    owner => 'root',
    group => 'root',
    mode  => '0644',
  }

  concat::fragment{ 'sp-config-file:header':
    target => $shibbolethsp::params::sp_config_file,
    content => template('shibbolethsp/shibboleth2.header.xml.erb'),
    order   => 01,
  }

  concat::fragment{ 'sp-config-file:footer':
    target => $shibbolethsp::params::sp_config_file,
    content => template('shibbolethsp/shibboleth2.footer.xml.erb'),
    order   => 99,
  }

  file { '/usr/share/shibboleth/logo.jpg':
    ensure => present,
    mode   => '0644',
    owner  => 'root',
    group  => 'root',
    source => 'puppet:///modules/shibbolethsp/logo.jpg',
  }

  if !$idp_sig_cert {
    warning ('No IdP sig cert provided; skipping.')
  } elsif !$idp_sig_cert_name {
    warning ('No IdP sig cert name provided; skipping.')
  } else {
    file { "/etc/shibboleth/${idp_sig_cert_name}":
      ensure => present,
      mode   => '0644',
      owner  => 'root',
      group  => 'root',
      content => $idp_sig_cert,
    }
  }

  if !$logout_redirect_uri {
    warning ('No logout redirection URI provided; skipping.')
  } else {
    file { '/etc/shibboleth/localLogout.html':
      ensure => present,
      mode   => '0644',
      owner  => 'root',
      group  => 'root',
      content => template('shibbolethsp/localLogout.html.erb'),
    }
  }

  file { '/etc/init/supervisord.conf':
    ensure => present,
    mode   => '0644',
    owner  => 'root',
    group  => 'root',
    source => 'puppet:///modules/shibbolethsp/supervisord.conf',
  }

  file { '/etc/supervisord.d/shibboleth.ini':
    ensure => present,
    mode   => '0644',
    owner  => 'root',
    group  => 'root',
    source => 'puppet:///modules/shibbolethsp/supervisor-fcgi-shibboleth.ini',
  }

  unless $sp_cert == '' {
    file { $shibbolethsp::params::sp_cert_file:
      ensure => file,
      mode   => '0644',
      owner  => 'shibd',
      group  => 'shibd',
      content => $sp_cert,
    }
  }

  unless $sp_key == '' {
    file { $shibbolethsp::params::sp_key_file:
      ensure => file,
      mode   => '0600',
      owner  => 'shibd',
      group  => 'shibd',
      content => $sp_key,
    }
  }

  user { $http_process_user:
    ensure => present,
    groups => ['shibd'],
    system => true,
    shell  => '/sbin/nologin',
  }

  concat{ $shibbolethsp::params::attribute_map_path:
    owner => 'root',
    group => 'root',
    mode  => '0644',
  }

  concat::fragment{ 'attribute map header':
    target => $shibbolethsp::params::attribute_map_path,
    content => template('shibbolethsp/attribute-map.header.xml.erb'),
    order   => 01,
  }

  shibbolethsp::attribute{ $sp_mapped_attributes:}

  concat::fragment{ 'attribute map footer':
    target => $shibbolethsp::params::attribute_map_path,
    content => template('shibbolethsp/attribute-map.footer.xml.erb'),
    order   => 99,
  }
}
